@@ -40,7 +40,7 @@
 #include <QCheckBox>
 #include <QRadioButton>
 #include <kurlrequester.h>
-#include <QtCore/QObject>
+#include <QObject>
 #include <QVector>
 #include <QMatrix>
 #include <QPaintEngine>
@@ -56,7 +56,7 @@
 #include "css/cssvalues.h"
 
 #include <kcolorscheme.h>
-#include <QDebug>
+#include "khtml_debug.h"
 
 //#define IN_PLACE_WIDGET_PAINTING
 
@@ -80,7 +80,7 @@ void RenderReplaced::calcMinMaxWidth()
     KHTMLAssert(!minMaxKnown());
 
 #ifdef DEBUG_LAYOUT
-    // qDebug() << "RenderReplaced::calcMinMaxWidth() known=" << minMaxKnown();
+    // qCDebug(KHTML_LOG) << "RenderReplaced::calcMinMaxWidth() known=" << minMaxKnown();
 #endif
 
     m_width = calcReplacedWidth() + borderLeft() + borderRight() + paddingLeft() + paddingRight();
@@ -100,9 +100,9 @@ void RenderReplaced::calcMinMaxWidth()
 FindSelectionResult RenderReplaced::checkSelectionPoint(int _x, int _y, int _tx, int _ty, DOM::NodeImpl *&node, int &offset, SelPointState &)
 {
 #if 0
-    // qDebug() << "RenderReplaced::checkSelectionPoint(_x="<<_x<<",_y="<<_y<<",_tx="<<_tx<<",_ty="<<_ty<<")" << endl
+    // qCDebug(KHTML_LOG) << "RenderReplaced::checkSelectionPoint(_x="<<_x<<",_y="<<_y<<",_tx="<<_tx<<",_ty="<<_ty<<")" << endl
             << "xPos: " << xPos() << " yPos: " << yPos() << " width: " << width() << " height: " << height() << endl
-            << "_ty + yPos: " << (_ty + yPos()) << " + height: " << (_ty + yPos() + height()) << "; _tx + xPos: " << (_tx + xPos()) << " + width: " << (_tx + xPos() + width()) << endl;
+            << "_ty + yPos: " << (_ty + yPos()) << " + height: " << (_ty + yPos() + height()) << "; _tx + xPos: " << (_tx + xPos()) << " + width: " << (_tx + xPos() + width());
 #endif
     node = element();
     offset = 0;
@@ -189,10 +189,10 @@ RenderPosition RenderReplaced::positionForCoordinates(int _x, int _y)
 RenderWidget::RenderWidget(DOM::NodeImpl *node)
     : RenderReplaced(node)
 {
-    m_widget = 0;
-    m_underMouse = 0;
-    m_buffer[0] = 0;
-    m_buffer[1] = 0;
+    m_widget = nullptr;
+    m_underMouse = nullptr;
+    m_buffer[0] = nullptr;
+    m_buffer[1] = nullptr;
     m_nativeFrameShape = QFrame::NoFrame;
     // a widget doesn't support being anonymous
     assert(!isAnonymous());
@@ -220,7 +220,7 @@ void RenderWidget::detach()
         }
         KHTMLWidget *k = dynamic_cast<KHTMLWidget *>(m_widget);
         if (k) {
-            k->m_kwp->setRenderWidget(0);
+            k->m_kwp->setRenderWidget(nullptr);
         }
         m_widget->removeEventFilter(this);
         m_widget->setMouseTracking(false);
@@ -228,7 +228,7 @@ void RenderWidget::detach()
 
     // make sure our DOM-node don't think we exist
     if (node() && node()->renderer() == this) {
-        node()->setRenderer(0);
+        node()->setRenderer(nullptr);
     }
 
     setDetached();
@@ -310,7 +310,7 @@ void RenderWidget::setQWidget(QWidget *widget)
             if (m_ownsWidget) {
                 m_widget->deleteLater();    //Might happen due to event on the widget, so be careful
             }
-            m_widget = 0;
+            m_widget = nullptr;
         }
         m_widget = widget;
         if (m_widget) {
@@ -555,7 +555,7 @@ void RenderWidget::slotWidgetDestructed()
     if (m_view) {
         m_view->setWidgetVisible(this, false);
     }
-    m_widget = 0;
+    m_widget = nullptr;
 }
 
 void RenderWidget::setStyle(RenderStyle *_style)
@@ -689,7 +689,7 @@ static void setInPaintEventFlag(QWidget *w, bool b = true, bool recurse = true)
     }
 }
 
-static void copyWidget(const QRect &r, QPainter *p, QWidget *widget, int tx, int ty, bool buffered = false, QPixmap *buffer = 0)
+static void copyWidget(const QRect &r, QPainter *p, QWidget *widget, int tx, int ty, bool buffered = false, QPixmap *buffer = nullptr)
 {
     if (r.isNull() || r.isEmpty()) {
         return;
@@ -702,7 +702,7 @@ static void copyWidget(const QRect &r, QPainter *p, QWidget *widget, int tx, int
         thePoint.setX(thePoint.x() + static_cast<int>(t.dx()));
         thePoint.setY(thePoint.y() + static_cast<int>(t.dy()));
     }
-    QPixmap *pm = 0;
+    QPixmap *pm = nullptr;
     QPaintDevice *d = p->device();
 #ifdef IN_PLACE_WIDGET_PAINTING
     QPaintDevice *x = d;
@@ -842,7 +842,7 @@ bool RenderWidget::eventFilter(QObject * /*o*/, QEvent *e)
 
     bool filtered = false;
 
-    //qDebug() << "RenderWidget::eventFilter type=" << e->type();
+    //qCDebug(KHTML_LOG) << "RenderWidget::eventFilter type=" << e->type();
     switch (e->type()) {
     case QEvent::FocusOut:
         // First, forward it to the widget, so that Qt gets a precise
@@ -865,7 +865,7 @@ bool RenderWidget::eventFilter(QObject * /*o*/, QEvent *e)
         directToWidget = false;
         filtered       = true; //We already delivered it!
 
-        //qDebug() << "RenderWidget::eventFilter captures FocusIn";
+        //qCDebug(KHTML_LOG) << "RenderWidget::eventFilter captures FocusIn";
         document()->setFocusNode(element());
 //         if ( isEditable() ) {
 //             KHTMLPartBrowserExtension *ext = static_cast<KHTMLPartBrowserExtension *>( element()->view->part()->browserExtension() );
@@ -969,7 +969,7 @@ static bool bubblingSend(QWidget *target, QEvent *e, QWidget *stoppingParent)
         }
         // ### might want to shift Q*Event::pos() as we go up
         target = target->parentWidget();
-        assert(target != 0);
+        assert(target != nullptr);
     }
 }
 
@@ -1001,7 +1001,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl &ev)
         QMouseEvent::Type type;
         Qt::MouseButton button = Qt::NoButton;
         Qt::MouseButtons buttons = Qt::NoButton;
-        Qt::KeyboardModifiers state = 0;
+        Qt::KeyboardModifiers state = nullptr;
         Qt::Orientation orient = Qt::Vertical;
 
         if (qme) {
@@ -1093,7 +1093,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl &ev)
             if (m_underMouse) {
                 QEvent moe(QEvent::Leave);
                 QApplication::sendEvent(m_underMouse, &moe);
-//                qDebug() << "sending LEAVE to"<< m_underMouse;
+//                qCDebug(KHTML_LOG) << "sending LEAVE to"<< m_underMouse;
                 if (m_underMouse->testAttribute(Qt::WA_Hover)) {
                     QHoverEvent he(QEvent::HoverLeave, QPoint(-1, -1), QPoint(0, 0));
                     QApplication::sendEvent(m_underMouse, &he);
@@ -1102,7 +1102,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl &ev)
             if (target) {
                 QEvent moe(QEvent::Enter);
                 QApplication::sendEvent(target, &moe);
-//                qDebug() << "sending ENTER to" << target;
+//                qCDebug(KHTML_LOG) << "sending ENTER to" << target;
                 if (target->testAttribute(Qt::WA_Hover)) {
                     QHoverEvent he(QEvent::HoverEnter, QPoint(0, 0), QPoint(-1, -1));
                     QApplication::sendEvent(target, &he);
@@ -1176,7 +1176,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl &ev)
             QApplication::sendEvent(target, &he);
         }
         if (ev.id() == EventImpl::MOUSEUP_EVENT) {
-            view()->setMouseEventsTarget(0);
+            view()->setMouseEventsTarget(nullptr);
         }
         break;
     }
@@ -1236,18 +1236,18 @@ bool RenderWidget::handleEvent(const DOM::EventImpl &ev)
         QWidget *target = m_underMouse ? (QWidget *) m_underMouse : m_widget;
         QEvent moe(QEvent::Leave);
         QApplication::sendEvent(target, &moe);
-//        qDebug() << "received MOUSEOUT, forwarding to" << target ;
+//        qCDebug(KHTML_LOG) << "received MOUSEOUT, forwarding to" << target ;
         if (target->testAttribute(Qt::WA_Hover)) {
             QHoverEvent he(QEvent::HoverLeave, QPoint(-1, -1), QPoint(0, 0));
             QApplication::sendEvent(target, &he);
         }
-        m_underMouse = 0;
+        m_underMouse = nullptr;
         break;
     }
     case EventImpl::MOUSEOVER_EVENT: {
         QEvent moe(QEvent::Enter);
         QApplication::sendEvent(m_widget, &moe);
-//        qDebug() << "received MOUSEOVER, forwarding to" << m_widget;
+//        qCDebug(KHTML_LOG) << "received MOUSEOVER, forwarding to" << m_widget;
         if (m_widget->testAttribute(Qt::WA_Hover)) {
             QHoverEvent he(QEvent::HoverEnter, QPoint(0, 0), QPoint(-1, -1));
             QApplication::sendEvent(m_widget, &he);
@@ -1310,11 +1310,11 @@ KHTMLView *KHTMLWidgetPrivate::rootViewPos(QPoint &pos)
 {
     if (!m_rw || !m_rw->widget()) {
         pos = QPoint();
-        return 0;
+        return nullptr;
     }
     pos = absolutePos();
     KHTMLView *v = m_rw->view();
-    KHTMLView *last = 0;
+    KHTMLView *last = nullptr;
     while (v) {
         last = v;
         int w, h = 0;
@@ -1324,7 +1324,7 @@ KHTMLView *KHTMLWidgetPrivate::rootViewPos(QPoint &pos)
             break;
         }
         pos += kw->m_kwp->absolutePos();
-        v = v->part()->parentPart() ? v->part()->parentPart()->view() : 0;
+        v = v->part()->parentPart() ? v->part()->parentPart()->view() : nullptr;
     }
     return last;
 }
